@@ -1,3 +1,4 @@
+use proc_macro::TokenStream;
 use quote::quote;
 use syn::{
     parse_macro_input, parse_quote_spanned,
@@ -17,7 +18,7 @@ use syn::{
 /// assert_eq!(s_array, expected);
 /// ```
 #[proc_macro]
-pub fn utf32(input: proc_macro::TokenStream) -> proc_macro::TokenStream {
+pub fn utf32(input: TokenStream) -> TokenStream {
     let mut expr = parse_macro_input!(input as Expr);
     Utf32Replace.visit_expr_mut(&mut expr);
     quote!(#expr).into()
@@ -37,3 +38,21 @@ impl VisitMut for Utf32Replace {
         visit_mut::visit_expr_mut(self, node);
     }
 }
+
+/// Converts all `&str` literals to `&[char]`.
+///
+/// ```rust
+/// use utf32_lit::utf32_all_strings;
+/// #[utf32_all_strings]
+/// mod strings {
+///     pub const NAME: &[char] = "hello";
+/// }
+///
+/// assert_eq!(strings::NAME, &['h', 'e', 'l', 'l', 'o']);
+/// ```
+#[proc_macro_attribute]
+pub fn utf32_all_strings(_attr: TokenStream, input: TokenStream) -> TokenStream {
+    let mut item = parse_macro_input!(input);
+    Utf32Replace.visit_item_mut(&mut item);
+    quote!(#item).into()
+}
